from django.apps import AppConfig


class AdminIntegrationConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_forge_ai.admin_integration"
    verbose_name = "Django Forge AI Admin Integration"

